@@ -15,15 +15,15 @@
 
 from neutron.api.v2 import attributes as attr
 from neutron.common import rpc as n_rpc
-from neutron.common import topics
 from neutron import context as neutron_context
-from neutron.i18n import _LW
 from neutron import manager
-from neutron.plugins.common import constants as const
+from neutron.plugins.common import constants as n_const
 from oslo_config import cfg
 from oslo_log import log as logging
 import oslo_messaging
 
+from neutron_fwaas._i18n import _LW
+from neutron_fwaas.common import fwaas_constants as f_const
 from neutron_fwaas.db.firewall import firewall_db
 from neutron_fwaas.db.firewall import firewall_router_insertion_db
 from neutron_fwaas.extensions import firewall as fw_ext
@@ -43,19 +43,19 @@ class FirewallCallbacks(object):
         """Agent uses this to set a firewall's status."""
         LOG.debug("Setting firewall %s to status: %s" % (firewall_id, status))
         # Sanitize status first
-        if status in (const.ACTIVE, const.DOWN, const.INACTIVE):
+        if status in (n_const.ACTIVE, n_const.DOWN, n_const.INACTIVE):
             to_update = status
         else:
-            to_update = const.ERROR
+            to_update = n_const.ERROR
         # ignore changing status if firewall expects to be deleted
         # That case means that while some pending operation has been
         # performed on the backend, neutron server received delete request
         # and changed firewall status to PENDING_DELETE
         updated = self.plugin.update_firewall_status(
-            context, firewall_id, to_update, not_in=(const.PENDING_DELETE,))
+            context, firewall_id, to_update, not_in=(n_const.PENDING_DELETE,))
         if updated:
             LOG.debug("firewall %s status set: %s" % (firewall_id, to_update))
-        return updated and to_update != const.ERROR
+        return updated and to_update != n_const.ERROR
 
     def firewall_deleted(self, context, firewall_id, **kwargs):
         """Agent uses this to indicate firewall is deleted."""
@@ -63,14 +63,14 @@ class FirewallCallbacks(object):
         with context.session.begin(subtransactions=True):
             fw_db = self.plugin._get_firewall(context, firewall_id)
             # allow to delete firewalls in ERROR state
-            if fw_db.status in (const.PENDING_DELETE, const.ERROR):
+            if fw_db.status in (n_const.PENDING_DELETE, n_const.ERROR):
                 self.plugin.delete_db_firewall_object(context, firewall_id)
                 return True
             else:
-                LOG.warn(_LW('Firewall %(fw)s unexpectedly deleted by agent, '
-                             'status was %(status)s'),
-                         {'fw': firewall_id, 'status': fw_db.status})
-                fw_db.update({"status": const.ERROR})
+                LOG.warning(_LW('Firewall %(fw)s unexpectedly deleted by '
+                                'agent, status was %(status)s'),
+                            {'fw': firewall_id, 'status': fw_db.status})
+                fw_db.update({"status": n_const.ERROR})
                 return False
 
     def get_firewalls_for_tenant(self, context, **kwargs):
@@ -80,7 +80,7 @@ class FirewallCallbacks(object):
         for fw in self.plugin.get_firewalls(context):
             fw_with_rules = self.plugin._make_firewall_dict_with_rules(
                 context, fw['id'])
-            if fw['status'] == const.PENDING_DELETE:
+            if fw['status'] == n_const.PENDING_DELETE:
                 fw_with_rules['add-router-ids'] = []
                 fw_with_rules['del-router-ids'] = (
                     self.plugin.get_firewall_routers(context, fw['id']))
@@ -148,7 +148,7 @@ class FirewallPlugin(
         self.start_rpc_listeners()
 
         self.agent_rpc = FirewallAgentApi(
-            topics.L3_AGENT,
+            f_const.L3_AGENT,
             cfg.CONF.host
         )
         firewall_db.subscribe()
@@ -156,13 +156,13 @@ class FirewallPlugin(
     def start_rpc_listeners(self):
         self.endpoints = [FirewallCallbacks(self)]
 
-        self.conn = n_rpc.create_connection(new=True)
+        self.conn = n_rpc.create_connection()
         self.conn.create_consumer(
-            topics.FIREWALL_PLUGIN, self.endpoints, fanout=False)
+            f_const.FIREWALL_PLUGIN, self.endpoints, fanout=False)
         return self.conn.consume_in_threads()
 
     def _rpc_update_firewall(self, context, firewall_id):
-        status_update = {"firewall": {"status": const.PENDING_UPDATE}}
+        status_update = {"firewall": {"status": n_const.PENDING_UPDATE}}
         super(FirewallPlugin, self).update_firewall(context, firewall_id,
                                                     status_update)
         fw_with_rules = self._make_firewall_dict_with_rules(context,
@@ -182,9 +182,9 @@ class FirewallPlugin(
 
     def _ensure_update_firewall(self, context, firewall_id):
         fwall = self.get_firewall(context, firewall_id)
-        if fwall['status'] in [const.PENDING_CREATE,
-                               const.PENDING_UPDATE,
-                               const.PENDING_DELETE]:
+        if fwall['status'] in [n_const.PENDING_CREATE,
+                               n_const.PENDING_UPDATE,
+                               n_const.PENDING_DELETE]:
             raise fw_ext.FirewallInPendingState(firewall_id=firewall_id,
                                                 pending_state=fwall['status'])
 
@@ -209,7 +209,7 @@ class FirewallPlugin(
             # old semantics router-ids keyword not specified pick up
             # all routers on tenant.
             l3_plugin = manager.NeutronManager.get_service_plugins().get(
-                const.L3_ROUTER_NAT)
+                n_const.L3_ROUTER_NAT)
             ctx = neutron_context.get_admin_context()
             routers = l3_plugin.get_routers(ctx)
             router_ids = [
@@ -231,16 +231,14 @@ class FirewallPlugin(
 
     def create_firewall(self, context, firewall):
         LOG.debug("create_firewall() called")
-        tenant_id = self._get_tenant_id_for_create(context,
-            firewall['firewall'])
 
         fw_new_rtrs = self._get_routers_for_create_firewall(
-            tenant_id, context, firewall)
+            firewall['firewall']['tenant_id'], context, firewall)
 
         if not fw_new_rtrs:
             # no messaging to agent needed, and fw needs to go
             # to INACTIVE(no associated rtrs) state.
-            status = const.INACTIVE
+            status = n_const.INACTIVE
             fw = super(FirewallPlugin, self).create_firewall(
                 context, firewall, status)
             fw['router_ids'] = []
@@ -289,13 +287,13 @@ class FirewallPlugin(
         if not fw_new_rtrs and not fw_current_rtrs:
             # no messaging to agent needed, and we need to continue
             # in INACTIVE state
-            firewall['firewall']['status'] = const.INACTIVE
+            firewall['firewall']['status'] = n_const.INACTIVE
             fw = super(FirewallPlugin, self).update_firewall(
                 context, id, firewall)
             fw['router_ids'] = []
             return fw
         else:
-            firewall['firewall']['status'] = const.PENDING_UPDATE
+            firewall['firewall']['status'] = n_const.PENDING_UPDATE
             fw = super(FirewallPlugin, self).update_firewall(
                 context, id, firewall)
             fw['router_ids'] = fw_new_rtrs
@@ -334,7 +332,7 @@ class FirewallPlugin(
             # no routers to delete on the agent side
             self.delete_db_firewall_object(context, id)
         else:
-            status = {"firewall": {"status": const.PENDING_DELETE}}
+            status = {"firewall": {"status": n_const.PENDING_DELETE}}
             super(FirewallPlugin, self).update_firewall(context, id, status)
             # Reflect state change in fw_with_rules
             fw_with_rules['status'] = status['firewall']['status']
