@@ -10,7 +10,7 @@
 
 ZUUL_CLONER=/usr/zuul-env/bin/zuul-cloner
 neutron_installed=$(echo "import neutron" | python 2>/dev/null ; echo $?)
-BRANCH_NAME=stable/liberty
+BRANCH_NAME=stable/mitaka
 
 set -e
 
